@@ -22,6 +22,9 @@ PLATFORM_LIST = (
     'express',
     'connect',
     'r',
+    'ruby',
+    'rails3',
+    'javascript',
 )
 
 
@@ -32,6 +35,7 @@ def client_guide(request, project, platform):
 
     key = ProjectKey.objects.get(user=request.user, project=project)
     dsn = key.get_dsn()
+    dsn_public = key.get_dsn(public=True)
 
     template = 'sentry/partial/client_config/%s.html' % (platform,)
 
@@ -40,6 +44,8 @@ def client_guide(request, project, platform):
         'platform_title': platform.title(),
         'project': project,
         'dsn': dsn,
+        'dsn_public': dsn_public,
+        'page': 'client_help'
     }
 
     if request.is_ajax():
