@@ -83,6 +83,8 @@ urlpatterns = patterns('',
     url(r'^account/projects/new/$', projects.new_project, name='sentry-new-project'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/edit/$', projects.manage_project,
         name='sentry-manage-project'),
+    url(r'^account/projects/(?P<project_id>[\w_-]+)/tags/$', projects.manage_project_tags,
+        name='sentry-manage-project-tags'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/docs/$', projects.client_help,
         name='sentry-project-client-help'),
     url(r'^account/projects/(?P<project_id>[\w_-]+)/docs/(?P<platform>%s)/$' % ('|'.join(re.escape(r) for r in docs.PLATFORM_LIST),),
